# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNatIpCidrsResult',
    'AwaitableGetNatIpCidrsResult',
    'get_nat_ip_cidrs',
    'get_nat_ip_cidrs_output',
]

@pulumi.output_type
class GetNatIpCidrsResult:
    """
    A collection of values returned by getNatIpCidrs.
    """
    def __init__(__self__, cidrs=None, id=None, ids=None, name_regex=None, names=None, nat_gateway_id=None, nat_ip_cidr_names=None, nat_ip_cidrs=None, output_file=None, status=None):
        if cidrs and not isinstance(cidrs, list):
            raise TypeError("Expected argument 'cidrs' to be a list")
        pulumi.set(__self__, "cidrs", cidrs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip_cidr_names and not isinstance(nat_ip_cidr_names, list):
            raise TypeError("Expected argument 'nat_ip_cidr_names' to be a list")
        pulumi.set(__self__, "nat_ip_cidr_names", nat_ip_cidr_names)
        if nat_ip_cidrs and not isinstance(nat_ip_cidrs, list):
            raise TypeError("Expected argument 'nat_ip_cidrs' to be a list")
        pulumi.set(__self__, "nat_ip_cidrs", nat_ip_cidrs)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def cidrs(self) -> Sequence['outputs.GetNatIpCidrsCidrResult']:
        return pulumi.get(self, "cidrs")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> str:
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIpCidrNames")
    def nat_ip_cidr_names(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "nat_ip_cidr_names")

    @property
    @pulumi.getter(name="natIpCidrs")
    def nat_ip_cidrs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "nat_ip_cidrs")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetNatIpCidrsResult(GetNatIpCidrsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNatIpCidrsResult(
            cidrs=self.cidrs,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            nat_gateway_id=self.nat_gateway_id,
            nat_ip_cidr_names=self.nat_ip_cidr_names,
            nat_ip_cidrs=self.nat_ip_cidrs,
            output_file=self.output_file,
            status=self.status)


def get_nat_ip_cidrs(ids: Optional[Sequence[str]] = None,
                     name_regex: Optional[str] = None,
                     nat_gateway_id: Optional[str] = None,
                     nat_ip_cidr_names: Optional[Sequence[str]] = None,
                     nat_ip_cidrs: Optional[Sequence[str]] = None,
                     output_file: Optional[str] = None,
                     status: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNatIpCidrsResult:
    """
    This data source provides the Vpc Nat Ip Cidrs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.136.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("vpcNatIpCidrId1", ids.cidrs[0].id)
    name_regex = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        name_regex="^my-NatIpCidr")
    pulumi.export("vpcNatIpCidrId2", name_regex.cidrs[0].id)
    status = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        ids=["example_value-1"],
        status="Available")
    pulumi.export("vpcNatIpCidrId3", status.cidrs[0].id)
    nat_ip_cidr = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        nat_ip_cidrs=["example_value-1"])
    pulumi.export("vpcNatIpCidrId4", nat_ip_cidr.cidrs[0].id)
    at_ip_cidr_name = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        nat_ip_cidr_names=["example_value-1"])
    pulumi.export("vpcNatIpCidrId5", at_ip_cidr_name.cidrs[0].id)
    ```


    :param Sequence[str] ids: A list of Nat Ip Cidr IDs.
    :param str name_regex: A regex string to filter results by Nat Ip Cidr name.
    :param str nat_gateway_id: NAT IP ADDRESS range to the security group of the Kafka VPC NAT gateway instance ID.
    :param Sequence[str] nat_ip_cidr_names: The name of the CIDR block that you want to query. Support up to `20`.
    :param Sequence[str] nat_ip_cidrs: The NAT CIDR block to be created. Support up to `20`. The CIDR block must meet the following conditions: It must be `10.0.0.0/8`, `172.16.0.0/12`, `192.168.0.0/16`, or one of their subnets. The subnet mask must be `16` to `32` bits in lengths. To use a public CIDR block as the NAT CIDR block, the VPC to which the VPC NAT gateway belongs must be authorized to use public CIDR blocks. For more information, see [Create a VPC NAT gateway](https://www.alibabacloud.com/help/doc-detail/268230.htm).
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the NAT IP address. Valid values:`Available`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['natGatewayId'] = nat_gateway_id
    __args__['natIpCidrNames'] = nat_ip_cidr_names
    __args__['natIpCidrs'] = nat_ip_cidrs
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getNatIpCidrs:getNatIpCidrs', __args__, opts=opts, typ=GetNatIpCidrsResult).value

    return AwaitableGetNatIpCidrsResult(
        cidrs=pulumi.get(__ret__, 'cidrs'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        nat_ip_cidr_names=pulumi.get(__ret__, 'nat_ip_cidr_names'),
        nat_ip_cidrs=pulumi.get(__ret__, 'nat_ip_cidrs'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))
def get_nat_ip_cidrs_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                            nat_gateway_id: Optional[pulumi.Input[str]] = None,
                            nat_ip_cidr_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            nat_ip_cidrs: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            status: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNatIpCidrsResult]:
    """
    This data source provides the Vpc Nat Ip Cidrs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.136.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("vpcNatIpCidrId1", ids.cidrs[0].id)
    name_regex = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        name_regex="^my-NatIpCidr")
    pulumi.export("vpcNatIpCidrId2", name_regex.cidrs[0].id)
    status = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        ids=["example_value-1"],
        status="Available")
    pulumi.export("vpcNatIpCidrId3", status.cidrs[0].id)
    nat_ip_cidr = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        nat_ip_cidrs=["example_value-1"])
    pulumi.export("vpcNatIpCidrId4", nat_ip_cidr.cidrs[0].id)
    at_ip_cidr_name = alicloud.vpc.get_nat_ip_cidrs(nat_gateway_id="example_value",
        nat_ip_cidr_names=["example_value-1"])
    pulumi.export("vpcNatIpCidrId5", at_ip_cidr_name.cidrs[0].id)
    ```


    :param Sequence[str] ids: A list of Nat Ip Cidr IDs.
    :param str name_regex: A regex string to filter results by Nat Ip Cidr name.
    :param str nat_gateway_id: NAT IP ADDRESS range to the security group of the Kafka VPC NAT gateway instance ID.
    :param Sequence[str] nat_ip_cidr_names: The name of the CIDR block that you want to query. Support up to `20`.
    :param Sequence[str] nat_ip_cidrs: The NAT CIDR block to be created. Support up to `20`. The CIDR block must meet the following conditions: It must be `10.0.0.0/8`, `172.16.0.0/12`, `192.168.0.0/16`, or one of their subnets. The subnet mask must be `16` to `32` bits in lengths. To use a public CIDR block as the NAT CIDR block, the VPC to which the VPC NAT gateway belongs must be authorized to use public CIDR blocks. For more information, see [Create a VPC NAT gateway](https://www.alibabacloud.com/help/doc-detail/268230.htm).
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the NAT IP address. Valid values:`Available`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['natGatewayId'] = nat_gateway_id
    __args__['natIpCidrNames'] = nat_ip_cidr_names
    __args__['natIpCidrs'] = nat_ip_cidrs
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getNatIpCidrs:getNatIpCidrs', __args__, opts=opts, typ=GetNatIpCidrsResult)
    return __ret__.apply(lambda __response__: GetNatIpCidrsResult(
        cidrs=pulumi.get(__response__, 'cidrs'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        nat_ip_cidr_names=pulumi.get(__response__, 'nat_ip_cidr_names'),
        nat_ip_cidrs=pulumi.get(__response__, 'nat_ip_cidrs'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConsumerChannelsChannelResult',
    'GetInstancesInstanceResult',
    'GetMigrationJobsJobResult',
    'GetSubscriptionJobsJobResult',
    'GetSubscriptionJobsJobSubscriptionHostResult',
    'GetSynchronizationJobsJobResult',
]

@pulumi.output_type
class GetConsumerChannelsChannelResult(dict):
    def __init__(__self__, *,
                 consumer_group_id: str,
                 consumer_group_name: str,
                 consumer_group_user_name: str,
                 consumption_checkpoint: str,
                 id: str,
                 message_delay: int,
                 unconsumed_data: int):
        """
        :param str consumer_group_id: The ID of the consumer group.
        :param str consumer_group_name: The name of the consumer group.
        :param str consumer_group_user_name: The username of the consumer group.
        :param str consumption_checkpoint: The time point when the client consumed the last message in the subscription channel.
        :param str id: The ID of the Consumer Channel.
        :param int message_delay: The message delay time, for the current time data subscription channel in the earliest time of unconsumed messages of the difference, in Unix timestamp format, which is measured in seconds.
        :param int unconsumed_data: The total number of unconsumed messages.
        """
        pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        pulumi.set(__self__, "consumer_group_name", consumer_group_name)
        pulumi.set(__self__, "consumer_group_user_name", consumer_group_user_name)
        pulumi.set(__self__, "consumption_checkpoint", consumption_checkpoint)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "message_delay", message_delay)
        pulumi.set(__self__, "unconsumed_data", unconsumed_data)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> str:
        """
        The ID of the consumer group.
        """
        return pulumi.get(self, "consumer_group_id")

    @property
    @pulumi.getter(name="consumerGroupName")
    def consumer_group_name(self) -> str:
        """
        The name of the consumer group.
        """
        return pulumi.get(self, "consumer_group_name")

    @property
    @pulumi.getter(name="consumerGroupUserName")
    def consumer_group_user_name(self) -> str:
        """
        The username of the consumer group.
        """
        return pulumi.get(self, "consumer_group_user_name")

    @property
    @pulumi.getter(name="consumptionCheckpoint")
    def consumption_checkpoint(self) -> str:
        """
        The time point when the client consumed the last message in the subscription channel.
        """
        return pulumi.get(self, "consumption_checkpoint")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Consumer Channel.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="messageDelay")
    def message_delay(self) -> int:
        """
        The message delay time, for the current time data subscription channel in the earliest time of unconsumed messages of the difference, in Unix timestamp format, which is measured in seconds.
        """
        return pulumi.get(self, "message_delay")

    @property
    @pulumi.getter(name="unconsumedData")
    def unconsumed_data(self) -> int:
        """
        The total number of unconsumed messages.
        """
        return pulumi.get(self, "unconsumed_data")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 destination_endpoint_engine_name: str,
                 destination_region: str,
                 dts_instance_id: str,
                 id: str,
                 instance_class: str,
                 instance_name: str,
                 payment_type: str,
                 resource_group_id: str,
                 source_endpoint_engine_name: str,
                 source_region: str,
                 status: str,
                 type: str,
                 tags: Optional[Mapping[str, str]] = None):
        """
        :param str create_time: Instance creation time
        :param str destination_endpoint_engine_name: The target database engine type.
        :param str destination_region: The destination instance region.
        :param str dts_instance_id: The ID of the subscription instance.
        :param str id: The ID of the instance.
        :param str instance_class: The type of the migration or synchronization instance.- The specifications of the migration instance: **xxlarge**, **xlarge**, **large**, **medium**, **small**.- The types of synchronization instances: **large**, **medium**, **small**, **micro**.
        :param str payment_type: The payment type of the resource.
        :param str resource_group_id: Resource Group ID
        :param str source_endpoint_engine_name: Source instance database engine type.
        :param str source_region: The source instance region.
        :param str status: Instance status.
        :param str type: The instance type. Valid values: -**MIGRATION**: MIGRATION.-**SYNC**: synchronization.-**SUBSCRIBE**: SUBSCRIBE.
        :param Mapping[str, str] tags: The tag value corresponding to the tag key.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "destination_endpoint_engine_name", destination_endpoint_engine_name)
        pulumi.set(__self__, "destination_region", destination_region)
        pulumi.set(__self__, "dts_instance_id", dts_instance_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_class", instance_class)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "source_endpoint_engine_name", source_endpoint_engine_name)
        pulumi.set(__self__, "source_region", source_region)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Instance creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="destinationEndpointEngineName")
    def destination_endpoint_engine_name(self) -> str:
        """
        The target database engine type.
        """
        return pulumi.get(self, "destination_endpoint_engine_name")

    @property
    @pulumi.getter(name="destinationRegion")
    def destination_region(self) -> str:
        """
        The destination instance region.
        """
        return pulumi.get(self, "destination_region")

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> str:
        """
        The ID of the subscription instance.
        """
        return pulumi.get(self, "dts_instance_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> str:
        """
        The type of the migration or synchronization instance.- The specifications of the migration instance: **xxlarge**, **xlarge**, **large**, **medium**, **small**.- The types of synchronization instances: **large**, **medium**, **small**, **micro**.
        """
        return pulumi.get(self, "instance_class")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> str:
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        Resource Group ID
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="sourceEndpointEngineName")
    def source_endpoint_engine_name(self) -> str:
        """
        Source instance database engine type.
        """
        return pulumi.get(self, "source_endpoint_engine_name")

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> str:
        """
        The source instance region.
        """
        return pulumi.get(self, "source_region")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Instance status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The instance type. Valid values: -**MIGRATION**: MIGRATION.-**SYNC**: synchronization.-**SUBSCRIBE**: SUBSCRIBE.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        The tag value corresponding to the tag key.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetMigrationJobsJobResult(dict):
    def __init__(__self__, *,
                 data_initialization: bool,
                 data_synchronization: bool,
                 db_list: str,
                 destination_endpoint_data_base_name: str,
                 destination_endpoint_engine_name: str,
                 destination_endpoint_instance_id: str,
                 destination_endpoint_instance_type: str,
                 destination_endpoint_ip: str,
                 destination_endpoint_oracle_sid: str,
                 destination_endpoint_port: str,
                 destination_endpoint_region: str,
                 destination_endpoint_user_name: str,
                 dts_instance_id: str,
                 dts_job_id: str,
                 dts_job_name: str,
                 id: str,
                 payment_type: str,
                 source_endpoint_database_name: str,
                 source_endpoint_engine_name: str,
                 source_endpoint_instance_id: str,
                 source_endpoint_instance_type: str,
                 source_endpoint_ip: str,
                 source_endpoint_oracle_sid: str,
                 source_endpoint_owner_id: str,
                 source_endpoint_port: str,
                 source_endpoint_region: str,
                 source_endpoint_role: str,
                 source_endpoint_user_name: str,
                 status: str,
                 structure_initialization: bool):
        """
        :param bool data_initialization: Whether or not to execute DTS supports schema migration, full data migration, or full-data initialization.
        :param bool data_synchronization: Whether to perform incremental data migration for migration types or synchronization values include:
        :param str db_list: The Migration object, in the format of JSON strings.
        :param str destination_endpoint_data_base_name: The name of migrate the database.
        :param str destination_endpoint_engine_name: The type of destination database.
        :param str destination_endpoint_instance_id: The ID of destination instance.
        :param str destination_endpoint_instance_type: The type of destination instance.
        :param str destination_endpoint_ip: The ip of source endpoint.
        :param str destination_endpoint_oracle_sid: The SID of Oracle database.
        :param str destination_endpoint_port: The port of source endpoint.
        :param str destination_endpoint_region: The region of destination instance.
        :param str destination_endpoint_user_name: The username of database account.
        :param str dts_instance_id: The Migration instance ID. The ID of `dts.MigrationInstance`.
        :param str dts_job_id: The ID of the Migration Job.
        :param str dts_job_name: The name of synchronization job.
        :param str id: The ID of the Migration Job. Its value is same as `dts_job_id`.
        :param str payment_type: The payment type of the Migration Instance.
        :param str source_endpoint_database_name: The name of migrate the database.
        :param str source_endpoint_engine_name: The type of source database.
        :param str source_endpoint_instance_id: The ID of source instance.
        :param str source_endpoint_instance_type: The type of source instance.
        :param str source_endpoint_ip: The ip of source endpoint.
        :param str source_endpoint_oracle_sid: The SID of Oracle database.
        :param str source_endpoint_owner_id: The Alibaba Cloud account ID to which the source instance belongs.
        :param str source_endpoint_port: The port of source endpoint.
        :param str source_endpoint_region: The region of source instance.
        :param str source_endpoint_role: The name of the role configured for the cloud account to which the source instance belongs.
        :param str source_endpoint_user_name: The username of database account.
        :param str status: The status of the resource.
        :param bool structure_initialization: Whether to perform a database table structure to migrate or initialization.
        """
        pulumi.set(__self__, "data_initialization", data_initialization)
        pulumi.set(__self__, "data_synchronization", data_synchronization)
        pulumi.set(__self__, "db_list", db_list)
        pulumi.set(__self__, "destination_endpoint_data_base_name", destination_endpoint_data_base_name)
        pulumi.set(__self__, "destination_endpoint_engine_name", destination_endpoint_engine_name)
        pulumi.set(__self__, "destination_endpoint_instance_id", destination_endpoint_instance_id)
        pulumi.set(__self__, "destination_endpoint_instance_type", destination_endpoint_instance_type)
        pulumi.set(__self__, "destination_endpoint_ip", destination_endpoint_ip)
        pulumi.set(__self__, "destination_endpoint_oracle_sid", destination_endpoint_oracle_sid)
        pulumi.set(__self__, "destination_endpoint_port", destination_endpoint_port)
        pulumi.set(__self__, "destination_endpoint_region", destination_endpoint_region)
        pulumi.set(__self__, "destination_endpoint_user_name", destination_endpoint_user_name)
        pulumi.set(__self__, "dts_instance_id", dts_instance_id)
        pulumi.set(__self__, "dts_job_id", dts_job_id)
        pulumi.set(__self__, "dts_job_name", dts_job_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "source_endpoint_database_name", source_endpoint_database_name)
        pulumi.set(__self__, "source_endpoint_engine_name", source_endpoint_engine_name)
        pulumi.set(__self__, "source_endpoint_instance_id", source_endpoint_instance_id)
        pulumi.set(__self__, "source_endpoint_instance_type", source_endpoint_instance_type)
        pulumi.set(__self__, "source_endpoint_ip", source_endpoint_ip)
        pulumi.set(__self__, "source_endpoint_oracle_sid", source_endpoint_oracle_sid)
        pulumi.set(__self__, "source_endpoint_owner_id", source_endpoint_owner_id)
        pulumi.set(__self__, "source_endpoint_port", source_endpoint_port)
        pulumi.set(__self__, "source_endpoint_region", source_endpoint_region)
        pulumi.set(__self__, "source_endpoint_role", source_endpoint_role)
        pulumi.set(__self__, "source_endpoint_user_name", source_endpoint_user_name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "structure_initialization", structure_initialization)

    @property
    @pulumi.getter(name="dataInitialization")
    def data_initialization(self) -> bool:
        """
        Whether or not to execute DTS supports schema migration, full data migration, or full-data initialization.
        """
        return pulumi.get(self, "data_initialization")

    @property
    @pulumi.getter(name="dataSynchronization")
    def data_synchronization(self) -> bool:
        """
        Whether to perform incremental data migration for migration types or synchronization values include:
        """
        return pulumi.get(self, "data_synchronization")

    @property
    @pulumi.getter(name="dbList")
    def db_list(self) -> str:
        """
        The Migration object, in the format of JSON strings.
        """
        return pulumi.get(self, "db_list")

    @property
    @pulumi.getter(name="destinationEndpointDataBaseName")
    def destination_endpoint_data_base_name(self) -> str:
        """
        The name of migrate the database.
        """
        return pulumi.get(self, "destination_endpoint_data_base_name")

    @property
    @pulumi.getter(name="destinationEndpointEngineName")
    def destination_endpoint_engine_name(self) -> str:
        """
        The type of destination database.
        """
        return pulumi.get(self, "destination_endpoint_engine_name")

    @property
    @pulumi.getter(name="destinationEndpointInstanceId")
    def destination_endpoint_instance_id(self) -> str:
        """
        The ID of destination instance.
        """
        return pulumi.get(self, "destination_endpoint_instance_id")

    @property
    @pulumi.getter(name="destinationEndpointInstanceType")
    def destination_endpoint_instance_type(self) -> str:
        """
        The type of destination instance.
        """
        return pulumi.get(self, "destination_endpoint_instance_type")

    @property
    @pulumi.getter(name="destinationEndpointIp")
    def destination_endpoint_ip(self) -> str:
        """
        The ip of source endpoint.
        """
        return pulumi.get(self, "destination_endpoint_ip")

    @property
    @pulumi.getter(name="destinationEndpointOracleSid")
    def destination_endpoint_oracle_sid(self) -> str:
        """
        The SID of Oracle database.
        """
        return pulumi.get(self, "destination_endpoint_oracle_sid")

    @property
    @pulumi.getter(name="destinationEndpointPort")
    def destination_endpoint_port(self) -> str:
        """
        The port of source endpoint.
        """
        return pulumi.get(self, "destination_endpoint_port")

    @property
    @pulumi.getter(name="destinationEndpointRegion")
    def destination_endpoint_region(self) -> str:
        """
        The region of destination instance.
        """
        return pulumi.get(self, "destination_endpoint_region")

    @property
    @pulumi.getter(name="destinationEndpointUserName")
    def destination_endpoint_user_name(self) -> str:
        """
        The username of database account.
        """
        return pulumi.get(self, "destination_endpoint_user_name")

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> str:
        """
        The Migration instance ID. The ID of `dts.MigrationInstance`.
        """
        return pulumi.get(self, "dts_instance_id")

    @property
    @pulumi.getter(name="dtsJobId")
    def dts_job_id(self) -> str:
        """
        The ID of the Migration Job.
        """
        return pulumi.get(self, "dts_job_id")

    @property
    @pulumi.getter(name="dtsJobName")
    def dts_job_name(self) -> str:
        """
        The name of synchronization job.
        """
        return pulumi.get(self, "dts_job_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Migration Job. Its value is same as `dts_job_id`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the Migration Instance.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="sourceEndpointDatabaseName")
    def source_endpoint_database_name(self) -> str:
        """
        The name of migrate the database.
        """
        return pulumi.get(self, "source_endpoint_database_name")

    @property
    @pulumi.getter(name="sourceEndpointEngineName")
    def source_endpoint_engine_name(self) -> str:
        """
        The type of source database.
        """
        return pulumi.get(self, "source_endpoint_engine_name")

    @property
    @pulumi.getter(name="sourceEndpointInstanceId")
    def source_endpoint_instance_id(self) -> str:
        """
        The ID of source instance.
        """
        return pulumi.get(self, "source_endpoint_instance_id")

    @property
    @pulumi.getter(name="sourceEndpointInstanceType")
    def source_endpoint_instance_type(self) -> str:
        """
        The type of source instance.
        """
        return pulumi.get(self, "source_endpoint_instance_type")

    @property
    @pulumi.getter(name="sourceEndpointIp")
    def source_endpoint_ip(self) -> str:
        """
        The ip of source endpoint.
        """
        return pulumi.get(self, "source_endpoint_ip")

    @property
    @pulumi.getter(name="sourceEndpointOracleSid")
    def source_endpoint_oracle_sid(self) -> str:
        """
        The SID of Oracle database.
        """
        return pulumi.get(self, "source_endpoint_oracle_sid")

    @property
    @pulumi.getter(name="sourceEndpointOwnerId")
    def source_endpoint_owner_id(self) -> str:
        """
        The Alibaba Cloud account ID to which the source instance belongs.
        """
        return pulumi.get(self, "source_endpoint_owner_id")

    @property
    @pulumi.getter(name="sourceEndpointPort")
    def source_endpoint_port(self) -> str:
        """
        The port of source endpoint.
        """
        return pulumi.get(self, "source_endpoint_port")

    @property
    @pulumi.getter(name="sourceEndpointRegion")
    def source_endpoint_region(self) -> str:
        """
        The region of source instance.
        """
        return pulumi.get(self, "source_endpoint_region")

    @property
    @pulumi.getter(name="sourceEndpointRole")
    def source_endpoint_role(self) -> str:
        """
        The name of the role configured for the cloud account to which the source instance belongs.
        """
        return pulumi.get(self, "source_endpoint_role")

    @property
    @pulumi.getter(name="sourceEndpointUserName")
    def source_endpoint_user_name(self) -> str:
        """
        The username of database account.
        """
        return pulumi.get(self, "source_endpoint_user_name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="structureInitialization")
    def structure_initialization(self) -> bool:
        """
        Whether to perform a database table structure to migrate or initialization.
        """
        return pulumi.get(self, "structure_initialization")


@pulumi.output_type
class GetSubscriptionJobsJobResult(dict):
    def __init__(__self__, *,
                 checkpoint: str,
                 create_time: str,
                 db_list: str,
                 dts_instance_id: str,
                 dts_job_id: str,
                 dts_job_name: str,
                 expire_time: str,
                 id: str,
                 payment_type: str,
                 source_endpoint_database_name: str,
                 source_endpoint_engine_name: str,
                 source_endpoint_instance_id: str,
                 source_endpoint_instance_type: str,
                 source_endpoint_ip: str,
                 source_endpoint_oracle_sid: str,
                 source_endpoint_owner_id: str,
                 source_endpoint_port: str,
                 source_endpoint_region: str,
                 source_endpoint_role: str,
                 source_endpoint_user_name: str,
                 status: str,
                 subscription_data_type_ddl: bool,
                 subscription_data_type_dml: bool,
                 subscription_hosts: Sequence['outputs.GetSubscriptionJobsJobSubscriptionHostResult'],
                 subscription_instance_network_type: str,
                 subscription_instance_vpc_id: str,
                 subscription_instance_vswitch_id: str,
                 tags: Mapping[str, str]):
        """
        :param str checkpoint: Subscription start time in Unix timestamp format.
        :param str create_time: The creation time of subscription job instance.
        :param str db_list: Subscription object, in the format of JSON strings.
        :param str dts_instance_id: The ID of subscription job instance.
        :param str dts_job_id: The ID of subscription job instance.
        :param str dts_job_name: The name of subscription job instance.
        :param str expire_time: The Expiration Time. Formatting with yyyy-MM-ddTHH:mm:ssZ(UTC time).
        :param str id: The ID of the Subscription Job.
        :param str payment_type: The payment type of the resource. Valid values: `Subscription`, `PayAsYouGo`.
        :param str source_endpoint_database_name: To subscribe to the name of the database.
        :param str source_endpoint_engine_name: The source database type value is MySQL or Oracle.
        :param str source_endpoint_instance_id: The ID of source instance. Only when the type of source database instance was RDS MySQL, PolarDB-X 1.0, PolarDB MySQL, this parameter can be available and must be set.
        :param str source_endpoint_instance_type: The type of source instance. Valid values: `RDS`, `PolarDB`, `DRDS`, `LocalInstance`, `ECS`, `Express`, `CEN`, `dg`.
        :param str source_endpoint_ip: The IP of source endpoint.
        :param str source_endpoint_oracle_sid: The SID of Oracle Database. When the source database is self-built Oracle and the Oracle database is a non-RAC instance, this parameter is available and must be passed in.
        :param str source_endpoint_owner_id: The Alibaba Cloud account ID to which the source instance belongs. This parameter is only available when configuring data subscriptions across Alibaba Cloud accounts and must be passed in.
        :param str source_endpoint_port: The  port of source database.
        :param str source_endpoint_region: The region of source database.
        :param str source_endpoint_role: Both the authorization roles. When the source instance and configure subscriptions task of the Alibaba Cloud account is not the same as the need to pass the parameter, to specify the source of the authorization roles, to allow configuration subscription task of the Alibaba Cloud account to access the source of the source instance information.
        :param str source_endpoint_user_name: The username of source database instance account.
        :param str status: The status of the task. Valid values: `NotStarted`, `Normal`, `Abnormal`. When a task created, it is in this state of `NotStarted`. You can specify this state of `Normal` to start the job, and specify this state of `Abnormal` to stop the job.
        :param bool subscription_data_type_ddl: Whether to subscribe the DDL type of data. Valid values: `true`, `false`.
        :param bool subscription_data_type_dml: Whether to subscribe the DML type of data. Valid values: `true`, `false`.
        :param Sequence['GetSubscriptionJobsJobSubscriptionHostArgs'] subscription_hosts: Network information.
        :param str subscription_instance_network_type: The type of subscription instance network. Valid value: `classic`, `vpc`.
        :param str subscription_instance_vpc_id: The ID of subscription instance vpc.
        :param str subscription_instance_vswitch_id: The ID of subscription instance vswitch.
        :param Mapping[str, str] tags: The tag of the resource.
        """
        pulumi.set(__self__, "checkpoint", checkpoint)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "db_list", db_list)
        pulumi.set(__self__, "dts_instance_id", dts_instance_id)
        pulumi.set(__self__, "dts_job_id", dts_job_id)
        pulumi.set(__self__, "dts_job_name", dts_job_name)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "source_endpoint_database_name", source_endpoint_database_name)
        pulumi.set(__self__, "source_endpoint_engine_name", source_endpoint_engine_name)
        pulumi.set(__self__, "source_endpoint_instance_id", source_endpoint_instance_id)
        pulumi.set(__self__, "source_endpoint_instance_type", source_endpoint_instance_type)
        pulumi.set(__self__, "source_endpoint_ip", source_endpoint_ip)
        pulumi.set(__self__, "source_endpoint_oracle_sid", source_endpoint_oracle_sid)
        pulumi.set(__self__, "source_endpoint_owner_id", source_endpoint_owner_id)
        pulumi.set(__self__, "source_endpoint_port", source_endpoint_port)
        pulumi.set(__self__, "source_endpoint_region", source_endpoint_region)
        pulumi.set(__self__, "source_endpoint_role", source_endpoint_role)
        pulumi.set(__self__, "source_endpoint_user_name", source_endpoint_user_name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "subscription_data_type_ddl", subscription_data_type_ddl)
        pulumi.set(__self__, "subscription_data_type_dml", subscription_data_type_dml)
        pulumi.set(__self__, "subscription_hosts", subscription_hosts)
        pulumi.set(__self__, "subscription_instance_network_type", subscription_instance_network_type)
        pulumi.set(__self__, "subscription_instance_vpc_id", subscription_instance_vpc_id)
        pulumi.set(__self__, "subscription_instance_vswitch_id", subscription_instance_vswitch_id)
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def checkpoint(self) -> str:
        """
        Subscription start time in Unix timestamp format.
        """
        return pulumi.get(self, "checkpoint")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of subscription job instance.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbList")
    def db_list(self) -> str:
        """
        Subscription object, in the format of JSON strings.
        """
        return pulumi.get(self, "db_list")

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> str:
        """
        The ID of subscription job instance.
        """
        return pulumi.get(self, "dts_instance_id")

    @property
    @pulumi.getter(name="dtsJobId")
    def dts_job_id(self) -> str:
        """
        The ID of subscription job instance.
        """
        return pulumi.get(self, "dts_job_id")

    @property
    @pulumi.getter(name="dtsJobName")
    def dts_job_name(self) -> str:
        """
        The name of subscription job instance.
        """
        return pulumi.get(self, "dts_job_name")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> str:
        """
        The Expiration Time. Formatting with yyyy-MM-ddTHH:mm:ssZ(UTC time).
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Subscription Job.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the resource. Valid values: `Subscription`, `PayAsYouGo`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="sourceEndpointDatabaseName")
    def source_endpoint_database_name(self) -> str:
        """
        To subscribe to the name of the database.
        """
        return pulumi.get(self, "source_endpoint_database_name")

    @property
    @pulumi.getter(name="sourceEndpointEngineName")
    def source_endpoint_engine_name(self) -> str:
        """
        The source database type value is MySQL or Oracle.
        """
        return pulumi.get(self, "source_endpoint_engine_name")

    @property
    @pulumi.getter(name="sourceEndpointInstanceId")
    def source_endpoint_instance_id(self) -> str:
        """
        The ID of source instance. Only when the type of source database instance was RDS MySQL, PolarDB-X 1.0, PolarDB MySQL, this parameter can be available and must be set.
        """
        return pulumi.get(self, "source_endpoint_instance_id")

    @property
    @pulumi.getter(name="sourceEndpointInstanceType")
    def source_endpoint_instance_type(self) -> str:
        """
        The type of source instance. Valid values: `RDS`, `PolarDB`, `DRDS`, `LocalInstance`, `ECS`, `Express`, `CEN`, `dg`.
        """
        return pulumi.get(self, "source_endpoint_instance_type")

    @property
    @pulumi.getter(name="sourceEndpointIp")
    def source_endpoint_ip(self) -> str:
        """
        The IP of source endpoint.
        """
        return pulumi.get(self, "source_endpoint_ip")

    @property
    @pulumi.getter(name="sourceEndpointOracleSid")
    def source_endpoint_oracle_sid(self) -> str:
        """
        The SID of Oracle Database. When the source database is self-built Oracle and the Oracle database is a non-RAC instance, this parameter is available and must be passed in.
        """
        return pulumi.get(self, "source_endpoint_oracle_sid")

    @property
    @pulumi.getter(name="sourceEndpointOwnerId")
    def source_endpoint_owner_id(self) -> str:
        """
        The Alibaba Cloud account ID to which the source instance belongs. This parameter is only available when configuring data subscriptions across Alibaba Cloud accounts and must be passed in.
        """
        return pulumi.get(self, "source_endpoint_owner_id")

    @property
    @pulumi.getter(name="sourceEndpointPort")
    def source_endpoint_port(self) -> str:
        """
        The  port of source database.
        """
        return pulumi.get(self, "source_endpoint_port")

    @property
    @pulumi.getter(name="sourceEndpointRegion")
    def source_endpoint_region(self) -> str:
        """
        The region of source database.
        """
        return pulumi.get(self, "source_endpoint_region")

    @property
    @pulumi.getter(name="sourceEndpointRole")
    def source_endpoint_role(self) -> str:
        """
        Both the authorization roles. When the source instance and configure subscriptions task of the Alibaba Cloud account is not the same as the need to pass the parameter, to specify the source of the authorization roles, to allow configuration subscription task of the Alibaba Cloud account to access the source of the source instance information.
        """
        return pulumi.get(self, "source_endpoint_role")

    @property
    @pulumi.getter(name="sourceEndpointUserName")
    def source_endpoint_user_name(self) -> str:
        """
        The username of source database instance account.
        """
        return pulumi.get(self, "source_endpoint_user_name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the task. Valid values: `NotStarted`, `Normal`, `Abnormal`. When a task created, it is in this state of `NotStarted`. You can specify this state of `Normal` to start the job, and specify this state of `Abnormal` to stop the job.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subscriptionDataTypeDdl")
    def subscription_data_type_ddl(self) -> bool:
        """
        Whether to subscribe the DDL type of data. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "subscription_data_type_ddl")

    @property
    @pulumi.getter(name="subscriptionDataTypeDml")
    def subscription_data_type_dml(self) -> bool:
        """
        Whether to subscribe the DML type of data. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "subscription_data_type_dml")

    @property
    @pulumi.getter(name="subscriptionHosts")
    def subscription_hosts(self) -> Sequence['outputs.GetSubscriptionJobsJobSubscriptionHostResult']:
        """
        Network information.
        """
        return pulumi.get(self, "subscription_hosts")

    @property
    @pulumi.getter(name="subscriptionInstanceNetworkType")
    def subscription_instance_network_type(self) -> str:
        """
        The type of subscription instance network. Valid value: `classic`, `vpc`.
        """
        return pulumi.get(self, "subscription_instance_network_type")

    @property
    @pulumi.getter(name="subscriptionInstanceVpcId")
    def subscription_instance_vpc_id(self) -> str:
        """
        The ID of subscription instance vpc.
        """
        return pulumi.get(self, "subscription_instance_vpc_id")

    @property
    @pulumi.getter(name="subscriptionInstanceVswitchId")
    def subscription_instance_vswitch_id(self) -> str:
        """
        The ID of subscription instance vswitch.
        """
        return pulumi.get(self, "subscription_instance_vswitch_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetSubscriptionJobsJobSubscriptionHostResult(dict):
    def __init__(__self__, *,
                 private_host: str,
                 public_host: str,
                 vpc_host: str):
        """
        :param str private_host: Classic network address.
        :param str public_host: Public network address.
        :param str vpc_host: VPC network address.
        """
        pulumi.set(__self__, "private_host", private_host)
        pulumi.set(__self__, "public_host", public_host)
        pulumi.set(__self__, "vpc_host", vpc_host)

    @property
    @pulumi.getter(name="privateHost")
    def private_host(self) -> str:
        """
        Classic network address.
        """
        return pulumi.get(self, "private_host")

    @property
    @pulumi.getter(name="publicHost")
    def public_host(self) -> str:
        """
        Public network address.
        """
        return pulumi.get(self, "public_host")

    @property
    @pulumi.getter(name="vpcHost")
    def vpc_host(self) -> str:
        """
        VPC network address.
        """
        return pulumi.get(self, "vpc_host")


@pulumi.output_type
class GetSynchronizationJobsJobResult(dict):
    def __init__(__self__, *,
                 checkpoint: str,
                 create_time: str,
                 data_initialization: bool,
                 data_synchronization: bool,
                 db_list: str,
                 destination_endpoint_data_base_name: str,
                 destination_endpoint_engine_name: str,
                 destination_endpoint_instance_id: str,
                 destination_endpoint_instance_type: str,
                 destination_endpoint_ip: str,
                 destination_endpoint_oracle_sid: str,
                 destination_endpoint_port: str,
                 destination_endpoint_region: str,
                 destination_endpoint_user_name: str,
                 dts_instance_id: str,
                 dts_job_id: str,
                 dts_job_name: str,
                 expire_time: str,
                 id: str,
                 source_endpoint_database_name: str,
                 source_endpoint_engine_name: str,
                 source_endpoint_instance_id: str,
                 source_endpoint_instance_type: str,
                 source_endpoint_ip: str,
                 source_endpoint_oracle_sid: str,
                 source_endpoint_owner_id: str,
                 source_endpoint_port: str,
                 source_endpoint_region: str,
                 source_endpoint_role: str,
                 source_endpoint_user_name: str,
                 status: str,
                 structure_initialization: bool,
                 synchronization_direction: str):
        """
        :param str checkpoint: Start time in Unix timestamp format.
        :param bool data_initialization: Whether to execute DTS supports schema migration, full data migration, or full-data initialization.
        :param bool data_synchronization: Whether to perform incremental data migration for migration types or synchronization.
        :param str db_list: Migration object, in the format of JSON strings. For detailed definition instructions, please refer to [the description of migration, synchronization or subscription objects](https://help.aliyun.com/document_detail/209545.html).
        :param str destination_endpoint_data_base_name: The name of migrate the database.
        :param str destination_endpoint_engine_name: The type of destination database. Valid values: `ADB20`, `ADB30`, `AS400`, `DATAHUB`, `DB2`, `GREENPLUM`, `KAFKA`, `MONGODB`, `MSSQL`, `MySQL`, `ORACLE`, `PolarDB`, `POLARDBX20`, `POLARDB_O`, `PostgreSQL`.
        :param str destination_endpoint_instance_id: The ID of destination instance.
        :param str destination_endpoint_instance_type: The type of destination instance. Valid values: `ads`, `CEN`, `DATAHUB`, `DG`, `ECS`, `EXPRESS`, `GREENPLUM`, `MONGODB`, `OTHER`, `PolarDB`, `POLARDBX20`, `RDS`.
        :param str destination_endpoint_ip: The ip of source endpoint.
        :param str destination_endpoint_oracle_sid: The SID of Oracle database.
        :param str destination_endpoint_port: The port of source endpoint.
        :param str destination_endpoint_region: The region of destination instance.
        :param str destination_endpoint_user_name: The username of database account.
        :param str dts_job_name: The name of synchronization job.
        :param str id: The ID of synchronizing instance. It's the ID of resource `dts.SynchronizationInstance`.
        :param str source_endpoint_database_name: The name of migrate the database.
        :param str source_endpoint_engine_name: The type of source database. Valid values: `AS400`, `DB2`, `DMSPOLARDB`, `HBASE`, `MONGODB`, `MSSQL`, `MySQL`, `ORACLE`, `PolarDB`, `POLARDBX20`, `POLARDB_O`, `POSTGRESQL`, `TERADATA`.
        :param str source_endpoint_instance_id: The ID of source instance.
        :param str source_endpoint_instance_type: The type of source instance. Valid values: `CEN`, `DG`, `DISTRIBUTED_DMSLOGICDB`, `ECS`, `EXPRESS`, `MONGODB`, `OTHER`, `PolarDB`, `POLARDBX20`, `RDS`.
        :param str source_endpoint_ip: The ip of source endpoint.
        :param str source_endpoint_oracle_sid: The SID of Oracle database.
        :param str source_endpoint_owner_id: The Alibaba Cloud account ID to which the source instance belongs.
        :param str source_endpoint_port: The port of source endpoint.
        :param str source_endpoint_region: The region of source instance.
        :param str source_endpoint_role: The name of the role configured for the cloud account to which the source instance belongs.
        :param str source_endpoint_user_name: The username of database account.
        :param str status: The status of the resource. Valid values: `Synchronizing`, `Suspending`. You can stop the task by specifying `Suspending` and start the task by specifying `Synchronizing`.
        :param bool structure_initialization: Whether to perform a database table structure to migrate or initialization values include:
        :param str synchronization_direction: Synchronization direction. Valid values: `Forward`, `Reverse`. Only when the property `sync_architecture` of the `dts.SynchronizationInstance` was `bidirectional` this parameter should be passed, otherwise this parameter should not be specified.
        """
        pulumi.set(__self__, "checkpoint", checkpoint)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "data_initialization", data_initialization)
        pulumi.set(__self__, "data_synchronization", data_synchronization)
        pulumi.set(__self__, "db_list", db_list)
        pulumi.set(__self__, "destination_endpoint_data_base_name", destination_endpoint_data_base_name)
        pulumi.set(__self__, "destination_endpoint_engine_name", destination_endpoint_engine_name)
        pulumi.set(__self__, "destination_endpoint_instance_id", destination_endpoint_instance_id)
        pulumi.set(__self__, "destination_endpoint_instance_type", destination_endpoint_instance_type)
        pulumi.set(__self__, "destination_endpoint_ip", destination_endpoint_ip)
        pulumi.set(__self__, "destination_endpoint_oracle_sid", destination_endpoint_oracle_sid)
        pulumi.set(__self__, "destination_endpoint_port", destination_endpoint_port)
        pulumi.set(__self__, "destination_endpoint_region", destination_endpoint_region)
        pulumi.set(__self__, "destination_endpoint_user_name", destination_endpoint_user_name)
        pulumi.set(__self__, "dts_instance_id", dts_instance_id)
        pulumi.set(__self__, "dts_job_id", dts_job_id)
        pulumi.set(__self__, "dts_job_name", dts_job_name)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "source_endpoint_database_name", source_endpoint_database_name)
        pulumi.set(__self__, "source_endpoint_engine_name", source_endpoint_engine_name)
        pulumi.set(__self__, "source_endpoint_instance_id", source_endpoint_instance_id)
        pulumi.set(__self__, "source_endpoint_instance_type", source_endpoint_instance_type)
        pulumi.set(__self__, "source_endpoint_ip", source_endpoint_ip)
        pulumi.set(__self__, "source_endpoint_oracle_sid", source_endpoint_oracle_sid)
        pulumi.set(__self__, "source_endpoint_owner_id", source_endpoint_owner_id)
        pulumi.set(__self__, "source_endpoint_port", source_endpoint_port)
        pulumi.set(__self__, "source_endpoint_region", source_endpoint_region)
        pulumi.set(__self__, "source_endpoint_role", source_endpoint_role)
        pulumi.set(__self__, "source_endpoint_user_name", source_endpoint_user_name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "structure_initialization", structure_initialization)
        pulumi.set(__self__, "synchronization_direction", synchronization_direction)

    @property
    @pulumi.getter
    def checkpoint(self) -> str:
        """
        Start time in Unix timestamp format.
        """
        return pulumi.get(self, "checkpoint")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataInitialization")
    def data_initialization(self) -> bool:
        """
        Whether to execute DTS supports schema migration, full data migration, or full-data initialization.
        """
        return pulumi.get(self, "data_initialization")

    @property
    @pulumi.getter(name="dataSynchronization")
    def data_synchronization(self) -> bool:
        """
        Whether to perform incremental data migration for migration types or synchronization.
        """
        return pulumi.get(self, "data_synchronization")

    @property
    @pulumi.getter(name="dbList")
    def db_list(self) -> str:
        """
        Migration object, in the format of JSON strings. For detailed definition instructions, please refer to [the description of migration, synchronization or subscription objects](https://help.aliyun.com/document_detail/209545.html).
        """
        return pulumi.get(self, "db_list")

    @property
    @pulumi.getter(name="destinationEndpointDataBaseName")
    def destination_endpoint_data_base_name(self) -> str:
        """
        The name of migrate the database.
        """
        return pulumi.get(self, "destination_endpoint_data_base_name")

    @property
    @pulumi.getter(name="destinationEndpointEngineName")
    def destination_endpoint_engine_name(self) -> str:
        """
        The type of destination database. Valid values: `ADB20`, `ADB30`, `AS400`, `DATAHUB`, `DB2`, `GREENPLUM`, `KAFKA`, `MONGODB`, `MSSQL`, `MySQL`, `ORACLE`, `PolarDB`, `POLARDBX20`, `POLARDB_O`, `PostgreSQL`.
        """
        return pulumi.get(self, "destination_endpoint_engine_name")

    @property
    @pulumi.getter(name="destinationEndpointInstanceId")
    def destination_endpoint_instance_id(self) -> str:
        """
        The ID of destination instance.
        """
        return pulumi.get(self, "destination_endpoint_instance_id")

    @property
    @pulumi.getter(name="destinationEndpointInstanceType")
    def destination_endpoint_instance_type(self) -> str:
        """
        The type of destination instance. Valid values: `ads`, `CEN`, `DATAHUB`, `DG`, `ECS`, `EXPRESS`, `GREENPLUM`, `MONGODB`, `OTHER`, `PolarDB`, `POLARDBX20`, `RDS`.
        """
        return pulumi.get(self, "destination_endpoint_instance_type")

    @property
    @pulumi.getter(name="destinationEndpointIp")
    def destination_endpoint_ip(self) -> str:
        """
        The ip of source endpoint.
        """
        return pulumi.get(self, "destination_endpoint_ip")

    @property
    @pulumi.getter(name="destinationEndpointOracleSid")
    def destination_endpoint_oracle_sid(self) -> str:
        """
        The SID of Oracle database.
        """
        return pulumi.get(self, "destination_endpoint_oracle_sid")

    @property
    @pulumi.getter(name="destinationEndpointPort")
    def destination_endpoint_port(self) -> str:
        """
        The port of source endpoint.
        """
        return pulumi.get(self, "destination_endpoint_port")

    @property
    @pulumi.getter(name="destinationEndpointRegion")
    def destination_endpoint_region(self) -> str:
        """
        The region of destination instance.
        """
        return pulumi.get(self, "destination_endpoint_region")

    @property
    @pulumi.getter(name="destinationEndpointUserName")
    def destination_endpoint_user_name(self) -> str:
        """
        The username of database account.
        """
        return pulumi.get(self, "destination_endpoint_user_name")

    @property
    @pulumi.getter(name="dtsInstanceId")
    def dts_instance_id(self) -> str:
        return pulumi.get(self, "dts_instance_id")

    @property
    @pulumi.getter(name="dtsJobId")
    def dts_job_id(self) -> str:
        return pulumi.get(self, "dts_job_id")

    @property
    @pulumi.getter(name="dtsJobName")
    def dts_job_name(self) -> str:
        """
        The name of synchronization job.
        """
        return pulumi.get(self, "dts_job_name")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> str:
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of synchronizing instance. It's the ID of resource `dts.SynchronizationInstance`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="sourceEndpointDatabaseName")
    def source_endpoint_database_name(self) -> str:
        """
        The name of migrate the database.
        """
        return pulumi.get(self, "source_endpoint_database_name")

    @property
    @pulumi.getter(name="sourceEndpointEngineName")
    def source_endpoint_engine_name(self) -> str:
        """
        The type of source database. Valid values: `AS400`, `DB2`, `DMSPOLARDB`, `HBASE`, `MONGODB`, `MSSQL`, `MySQL`, `ORACLE`, `PolarDB`, `POLARDBX20`, `POLARDB_O`, `POSTGRESQL`, `TERADATA`.
        """
        return pulumi.get(self, "source_endpoint_engine_name")

    @property
    @pulumi.getter(name="sourceEndpointInstanceId")
    def source_endpoint_instance_id(self) -> str:
        """
        The ID of source instance.
        """
        return pulumi.get(self, "source_endpoint_instance_id")

    @property
    @pulumi.getter(name="sourceEndpointInstanceType")
    def source_endpoint_instance_type(self) -> str:
        """
        The type of source instance. Valid values: `CEN`, `DG`, `DISTRIBUTED_DMSLOGICDB`, `ECS`, `EXPRESS`, `MONGODB`, `OTHER`, `PolarDB`, `POLARDBX20`, `RDS`.
        """
        return pulumi.get(self, "source_endpoint_instance_type")

    @property
    @pulumi.getter(name="sourceEndpointIp")
    def source_endpoint_ip(self) -> str:
        """
        The ip of source endpoint.
        """
        return pulumi.get(self, "source_endpoint_ip")

    @property
    @pulumi.getter(name="sourceEndpointOracleSid")
    def source_endpoint_oracle_sid(self) -> str:
        """
        The SID of Oracle database.
        """
        return pulumi.get(self, "source_endpoint_oracle_sid")

    @property
    @pulumi.getter(name="sourceEndpointOwnerId")
    def source_endpoint_owner_id(self) -> str:
        """
        The Alibaba Cloud account ID to which the source instance belongs.
        """
        return pulumi.get(self, "source_endpoint_owner_id")

    @property
    @pulumi.getter(name="sourceEndpointPort")
    def source_endpoint_port(self) -> str:
        """
        The port of source endpoint.
        """
        return pulumi.get(self, "source_endpoint_port")

    @property
    @pulumi.getter(name="sourceEndpointRegion")
    def source_endpoint_region(self) -> str:
        """
        The region of source instance.
        """
        return pulumi.get(self, "source_endpoint_region")

    @property
    @pulumi.getter(name="sourceEndpointRole")
    def source_endpoint_role(self) -> str:
        """
        The name of the role configured for the cloud account to which the source instance belongs.
        """
        return pulumi.get(self, "source_endpoint_role")

    @property
    @pulumi.getter(name="sourceEndpointUserName")
    def source_endpoint_user_name(self) -> str:
        """
        The username of database account.
        """
        return pulumi.get(self, "source_endpoint_user_name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid values: `Synchronizing`, `Suspending`. You can stop the task by specifying `Suspending` and start the task by specifying `Synchronizing`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="structureInitialization")
    def structure_initialization(self) -> bool:
        """
        Whether to perform a database table structure to migrate or initialization values include:
        """
        return pulumi.get(self, "structure_initialization")

    @property
    @pulumi.getter(name="synchronizationDirection")
    def synchronization_direction(self) -> str:
        """
        Synchronization direction. Valid values: `Forward`, `Reverse`. Only when the property `sync_architecture` of the `dts.SynchronizationInstance` was `bidirectional` this parameter should be passed, otherwise this parameter should not be specified.
        """
        return pulumi.get(self, "synchronization_direction")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConsumerGroupArgs', 'ConsumerGroup']

@pulumi.input_type
class ConsumerGroupArgs:
    def __init__(__self__, *,
                 consume_retry_policy: pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs'],
                 consumer_group_id: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 delivery_order_type: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ConsumerGroup resource.
        :param pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs'] consume_retry_policy: Consumption retry strategy. See `consume_retry_policy` below.
        :param pulumi.Input[str] consumer_group_id: The first ID of the resource.
        :param pulumi.Input[str] instance_id: Instance ID.
        :param pulumi.Input[str] delivery_order_type: Delivery order.
        :param pulumi.Input[str] remark: Custom remarks.
        """
        pulumi.set(__self__, "consume_retry_policy", consume_retry_policy)
        pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if delivery_order_type is not None:
            pulumi.set(__self__, "delivery_order_type", delivery_order_type)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)

    @property
    @pulumi.getter(name="consumeRetryPolicy")
    def consume_retry_policy(self) -> pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs']:
        """
        Consumption retry strategy. See `consume_retry_policy` below.
        """
        return pulumi.get(self, "consume_retry_policy")

    @consume_retry_policy.setter
    def consume_retry_policy(self, value: pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs']):
        pulumi.set(self, "consume_retry_policy", value)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> pulumi.Input[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "consumer_group_id")

    @consumer_group_id.setter
    def consumer_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "consumer_group_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        Instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="deliveryOrderType")
    def delivery_order_type(self) -> Optional[pulumi.Input[str]]:
        """
        Delivery order.
        """
        return pulumi.get(self, "delivery_order_type")

    @delivery_order_type.setter
    def delivery_order_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delivery_order_type", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        Custom remarks.
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)


@pulumi.input_type
class _ConsumerGroupState:
    def __init__(__self__, *,
                 consume_retry_policy: Optional[pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs']] = None,
                 consumer_group_id: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 delivery_order_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConsumerGroup resources.
        :param pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs'] consume_retry_policy: Consumption retry strategy. See `consume_retry_policy` below.
        :param pulumi.Input[str] consumer_group_id: The first ID of the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] delivery_order_type: Delivery order.
        :param pulumi.Input[str] instance_id: Instance ID.
        :param pulumi.Input[str] remark: Custom remarks.
        :param pulumi.Input[str] status: The status of the resource.
        """
        if consume_retry_policy is not None:
            pulumi.set(__self__, "consume_retry_policy", consume_retry_policy)
        if consumer_group_id is not None:
            pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delivery_order_type is not None:
            pulumi.set(__self__, "delivery_order_type", delivery_order_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="consumeRetryPolicy")
    def consume_retry_policy(self) -> Optional[pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs']]:
        """
        Consumption retry strategy. See `consume_retry_policy` below.
        """
        return pulumi.get(self, "consume_retry_policy")

    @consume_retry_policy.setter
    def consume_retry_policy(self, value: Optional[pulumi.Input['ConsumerGroupConsumeRetryPolicyArgs']]):
        pulumi.set(self, "consume_retry_policy", value)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "consumer_group_id")

    @consumer_group_id.setter
    def consumer_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deliveryOrderType")
    def delivery_order_type(self) -> Optional[pulumi.Input[str]]:
        """
        Delivery order.
        """
        return pulumi.get(self, "delivery_order_type")

    @delivery_order_type.setter
    def delivery_order_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delivery_order_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        Instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        Custom remarks.
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ConsumerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consume_retry_policy: Optional[pulumi.Input[Union['ConsumerGroupConsumeRetryPolicyArgs', 'ConsumerGroupConsumeRetryPolicyArgsDict']]] = None,
                 consumer_group_id: Optional[pulumi.Input[str]] = None,
                 delivery_order_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a RocketMQ Consumer Group resource.

        For information about RocketMQ Consumer Group and how to use it, see [What is Consumer Group](https://www.alibabacloud.com/help/en/apsaramq-for-rocketmq/cloud-message-queue-rocketmq-5-x-series/developer-reference/api-rocketmq-2022-08-01-createconsumergroup).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        create_vpc = alicloud.vpc.Network("createVpc",
            description="example",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        create_vswitch = alicloud.vpc.Switch("createVswitch",
            description="example",
            vpc_id=create_vpc.id,
            zone_id=default.zones[0].id,
            cidr_block="172.16.0.0/24",
            vswitch_name=name)
        create_instance = alicloud.rocketmq.RocketMQInstance("createInstance",
            auto_renew_period=1,
            product_info={
                "msg_process_spec": "rmq.p2.4xlarge",
                "send_receive_ratio": 0.3,
                "message_retention_time": 70,
            },
            network_info={
                "vpc_info": {
                    "vpc_id": create_vpc.id,
                    "vswitch_id": create_vswitch.id,
                },
                "internet_info": {
                    "internet_spec": "enable",
                    "flow_out_type": "payByBandwidth",
                    "flow_out_bandwidth": 30,
                },
            },
            period=1,
            sub_series_code="cluster_ha",
            remark="example",
            instance_name=name,
            service_code="rmq",
            series_code="professional",
            payment_type="PayAsYouGo",
            period_unit="Month")
        default_consumer_group = alicloud.rocketmq.ConsumerGroup("default",
            consumer_group_id=name,
            instance_id=create_instance.id,
            consume_retry_policy={
                "retry_policy": "DefaultRetryPolicy",
                "max_retry_times": 10,
            },
            delivery_order_type="Concurrently",
            remark="example")
        ```

        ## Import

        RocketMQ Consumer Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rocketmq/consumerGroup:ConsumerGroup example <instance_id>:<consumer_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ConsumerGroupConsumeRetryPolicyArgs', 'ConsumerGroupConsumeRetryPolicyArgsDict']] consume_retry_policy: Consumption retry strategy. See `consume_retry_policy` below.
        :param pulumi.Input[str] consumer_group_id: The first ID of the resource.
        :param pulumi.Input[str] delivery_order_type: Delivery order.
        :param pulumi.Input[str] instance_id: Instance ID.
        :param pulumi.Input[str] remark: Custom remarks.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConsumerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RocketMQ Consumer Group resource.

        For information about RocketMQ Consumer Group and how to use it, see [What is Consumer Group](https://www.alibabacloud.com/help/en/apsaramq-for-rocketmq/cloud-message-queue-rocketmq-5-x-series/developer-reference/api-rocketmq-2022-08-01-createconsumergroup).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        create_vpc = alicloud.vpc.Network("createVpc",
            description="example",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        create_vswitch = alicloud.vpc.Switch("createVswitch",
            description="example",
            vpc_id=create_vpc.id,
            zone_id=default.zones[0].id,
            cidr_block="172.16.0.0/24",
            vswitch_name=name)
        create_instance = alicloud.rocketmq.RocketMQInstance("createInstance",
            auto_renew_period=1,
            product_info={
                "msg_process_spec": "rmq.p2.4xlarge",
                "send_receive_ratio": 0.3,
                "message_retention_time": 70,
            },
            network_info={
                "vpc_info": {
                    "vpc_id": create_vpc.id,
                    "vswitch_id": create_vswitch.id,
                },
                "internet_info": {
                    "internet_spec": "enable",
                    "flow_out_type": "payByBandwidth",
                    "flow_out_bandwidth": 30,
                },
            },
            period=1,
            sub_series_code="cluster_ha",
            remark="example",
            instance_name=name,
            service_code="rmq",
            series_code="professional",
            payment_type="PayAsYouGo",
            period_unit="Month")
        default_consumer_group = alicloud.rocketmq.ConsumerGroup("default",
            consumer_group_id=name,
            instance_id=create_instance.id,
            consume_retry_policy={
                "retry_policy": "DefaultRetryPolicy",
                "max_retry_times": 10,
            },
            delivery_order_type="Concurrently",
            remark="example")
        ```

        ## Import

        RocketMQ Consumer Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rocketmq/consumerGroup:ConsumerGroup example <instance_id>:<consumer_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 consume_retry_policy: Optional[pulumi.Input[Union['ConsumerGroupConsumeRetryPolicyArgs', 'ConsumerGroupConsumeRetryPolicyArgsDict']]] = None,
                 consumer_group_id: Optional[pulumi.Input[str]] = None,
                 delivery_order_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerGroupArgs.__new__(ConsumerGroupArgs)

            if consume_retry_policy is None and not opts.urn:
                raise TypeError("Missing required property 'consume_retry_policy'")
            __props__.__dict__["consume_retry_policy"] = consume_retry_policy
            if consumer_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_group_id'")
            __props__.__dict__["consumer_group_id"] = consumer_group_id
            __props__.__dict__["delivery_order_type"] = delivery_order_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["remark"] = remark
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(ConsumerGroup, __self__).__init__(
            'alicloud:rocketmq/consumerGroup:ConsumerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            consume_retry_policy: Optional[pulumi.Input[Union['ConsumerGroupConsumeRetryPolicyArgs', 'ConsumerGroupConsumeRetryPolicyArgsDict']]] = None,
            consumer_group_id: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            delivery_order_type: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            remark: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ConsumerGroup':
        """
        Get an existing ConsumerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ConsumerGroupConsumeRetryPolicyArgs', 'ConsumerGroupConsumeRetryPolicyArgsDict']] consume_retry_policy: Consumption retry strategy. See `consume_retry_policy` below.
        :param pulumi.Input[str] consumer_group_id: The first ID of the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] delivery_order_type: Delivery order.
        :param pulumi.Input[str] instance_id: Instance ID.
        :param pulumi.Input[str] remark: Custom remarks.
        :param pulumi.Input[str] status: The status of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerGroupState.__new__(_ConsumerGroupState)

        __props__.__dict__["consume_retry_policy"] = consume_retry_policy
        __props__.__dict__["consumer_group_id"] = consumer_group_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delivery_order_type"] = delivery_order_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["remark"] = remark
        __props__.__dict__["status"] = status
        return ConsumerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="consumeRetryPolicy")
    def consume_retry_policy(self) -> pulumi.Output['outputs.ConsumerGroupConsumeRetryPolicy']:
        """
        Consumption retry strategy. See `consume_retry_policy` below.
        """
        return pulumi.get(self, "consume_retry_policy")

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "consumer_group_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deliveryOrderType")
    def delivery_order_type(self) -> pulumi.Output[Optional[str]]:
        """
        Delivery order.
        """
        return pulumi.get(self, "delivery_order_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        Instance ID.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def remark(self) -> pulumi.Output[Optional[str]]:
        """
        Custom remarks.
        """
        return pulumi.get(self, "remark")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PhysicalConnectionArgs', 'PhysicalConnection']

@pulumi.input_type
class PhysicalConnectionArgs:
    def __init__(__self__, *,
                 access_point_id: pulumi.Input[str],
                 line_operator: pulumi.Input[str],
                 bandwidth: Optional[pulumi.Input[str]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 peer_location: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 physical_connection_name: Optional[pulumi.Input[str]] = None,
                 port_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PhysicalConnection resource.
        :param pulumi.Input[str] access_point_id: The access point ID of the Express Connect circuit.
        :param pulumi.Input[str] line_operator: The connectivity provider of the Express Connect circuit. Valid values:
               - `CT`: China Telecom.
               - `CU`: China Unicom.
               - `CM`: China Mobile.
               - `CO`: Other connectivity providers in the Chinese mainland.
               - `Equinix`: Equinix.
               - `Other`: Other connectivity providers outside the Chinese mainland.
        :param pulumi.Input[str] bandwidth: The maximum bandwidth of the hosted connection.
        :param pulumi.Input[str] circuit_code: The circuit code of the Express Connect circuit.
        :param pulumi.Input[str] description: The description of the Express Connect circuit.
        :param pulumi.Input[str] peer_location: The geographical location of the data center.
        :param pulumi.Input[int] period: The subscription duration. Valid values:
               - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
               - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        :param pulumi.Input[str] physical_connection_name: The name of the Express Connect circuit.
        :param pulumi.Input[str] port_type: The port type of the Express Connect circuit. Valid values:
               - `100Base-T`: 100 Mbit/s copper Ethernet port.
               - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
               - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
               - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
               - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
               - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
               - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
               > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        :param pulumi.Input[str] pricing_cycle: The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
               > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        :param pulumi.Input[str] status: The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        :param pulumi.Input[str] type: The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "line_operator", line_operator)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if circuit_code is not None:
            pulumi.set(__self__, "circuit_code", circuit_code)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if peer_location is not None:
            pulumi.set(__self__, "peer_location", peer_location)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if physical_connection_name is not None:
            pulumi.set(__self__, "physical_connection_name", physical_connection_name)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if redundant_physical_connection_id is not None:
            pulumi.set(__self__, "redundant_physical_connection_id", redundant_physical_connection_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> pulumi.Input[str]:
        """
        The access point ID of the Express Connect circuit.
        """
        return pulumi.get(self, "access_point_id")

    @access_point_id.setter
    def access_point_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_point_id", value)

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> pulumi.Input[str]:
        """
        The connectivity provider of the Express Connect circuit. Valid values:
        - `CT`: China Telecom.
        - `CU`: China Unicom.
        - `CM`: China Mobile.
        - `CO`: Other connectivity providers in the Chinese mainland.
        - `Equinix`: Equinix.
        - `Other`: Other connectivity providers outside the Chinese mainland.
        """
        return pulumi.get(self, "line_operator")

    @line_operator.setter
    def line_operator(self, value: pulumi.Input[str]):
        pulumi.set(self, "line_operator", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum bandwidth of the hosted connection.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> Optional[pulumi.Input[str]]:
        """
        The circuit code of the Express Connect circuit.
        """
        return pulumi.get(self, "circuit_code")

    @circuit_code.setter
    def circuit_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "circuit_code", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Express Connect circuit.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> Optional[pulumi.Input[str]]:
        """
        The geographical location of the data center.
        """
        return pulumi.get(self, "peer_location")

    @peer_location.setter
    def peer_location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_location", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The subscription duration. Valid values:
        - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
        - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="physicalConnectionName")
    def physical_connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Express Connect circuit.
        """
        return pulumi.get(self, "physical_connection_name")

    @physical_connection_name.setter
    def physical_connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "physical_connection_name", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[str]]:
        """
        The port type of the Express Connect circuit. Valid values:
        - `100Base-T`: 100 Mbit/s copper Ethernet port.
        - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
        - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
        - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
        - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
        - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
        - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
        > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_type", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
        > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @redundant_physical_connection_id.setter
    def redundant_physical_connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redundant_physical_connection_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _PhysicalConnectionState:
    def __init__(__self__, *,
                 access_point_id: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[str]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 line_operator: Optional[pulumi.Input[str]] = None,
                 order_id: Optional[pulumi.Input[str]] = None,
                 peer_location: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 physical_connection_name: Optional[pulumi.Input[str]] = None,
                 port_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PhysicalConnection resources.
        :param pulumi.Input[str] access_point_id: The access point ID of the Express Connect circuit.
        :param pulumi.Input[str] bandwidth: The maximum bandwidth of the hosted connection.
        :param pulumi.Input[str] circuit_code: The circuit code of the Express Connect circuit.
        :param pulumi.Input[str] description: The description of the Express Connect circuit.
        :param pulumi.Input[str] line_operator: The connectivity provider of the Express Connect circuit. Valid values:
               - `CT`: China Telecom.
               - `CU`: China Unicom.
               - `CM`: China Mobile.
               - `CO`: Other connectivity providers in the Chinese mainland.
               - `Equinix`: Equinix.
               - `Other`: Other connectivity providers outside the Chinese mainland.
        :param pulumi.Input[str] order_id: The ID of the order that is placed. **Note:** `order_id` takes effect only if `status` is set to `Enabled`.
        :param pulumi.Input[str] peer_location: The geographical location of the data center.
        :param pulumi.Input[int] period: The subscription duration. Valid values:
               - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
               - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        :param pulumi.Input[str] physical_connection_name: The name of the Express Connect circuit.
        :param pulumi.Input[str] port_type: The port type of the Express Connect circuit. Valid values:
               - `100Base-T`: 100 Mbit/s copper Ethernet port.
               - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
               - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
               - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
               - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
               - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
               - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
               > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        :param pulumi.Input[str] pricing_cycle: The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
               > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        :param pulumi.Input[str] status: The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        :param pulumi.Input[str] type: The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        if access_point_id is not None:
            pulumi.set(__self__, "access_point_id", access_point_id)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if circuit_code is not None:
            pulumi.set(__self__, "circuit_code", circuit_code)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if line_operator is not None:
            pulumi.set(__self__, "line_operator", line_operator)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)
        if peer_location is not None:
            pulumi.set(__self__, "peer_location", peer_location)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if physical_connection_name is not None:
            pulumi.set(__self__, "physical_connection_name", physical_connection_name)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if redundant_physical_connection_id is not None:
            pulumi.set(__self__, "redundant_physical_connection_id", redundant_physical_connection_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> Optional[pulumi.Input[str]]:
        """
        The access point ID of the Express Connect circuit.
        """
        return pulumi.get(self, "access_point_id")

    @access_point_id.setter
    def access_point_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_point_id", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum bandwidth of the hosted connection.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> Optional[pulumi.Input[str]]:
        """
        The circuit code of the Express Connect circuit.
        """
        return pulumi.get(self, "circuit_code")

    @circuit_code.setter
    def circuit_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "circuit_code", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Express Connect circuit.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> Optional[pulumi.Input[str]]:
        """
        The connectivity provider of the Express Connect circuit. Valid values:
        - `CT`: China Telecom.
        - `CU`: China Unicom.
        - `CM`: China Mobile.
        - `CO`: Other connectivity providers in the Chinese mainland.
        - `Equinix`: Equinix.
        - `Other`: Other connectivity providers outside the Chinese mainland.
        """
        return pulumi.get(self, "line_operator")

    @line_operator.setter
    def line_operator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line_operator", value)

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the order that is placed. **Note:** `order_id` takes effect only if `status` is set to `Enabled`.
        """
        return pulumi.get(self, "order_id")

    @order_id.setter
    def order_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "order_id", value)

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> Optional[pulumi.Input[str]]:
        """
        The geographical location of the data center.
        """
        return pulumi.get(self, "peer_location")

    @peer_location.setter
    def peer_location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_location", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The subscription duration. Valid values:
        - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
        - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="physicalConnectionName")
    def physical_connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Express Connect circuit.
        """
        return pulumi.get(self, "physical_connection_name")

    @physical_connection_name.setter
    def physical_connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "physical_connection_name", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[str]]:
        """
        The port type of the Express Connect circuit. Valid values:
        - `100Base-T`: 100 Mbit/s copper Ethernet port.
        - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
        - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
        - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
        - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
        - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
        - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
        > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_type", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
        > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @redundant_physical_connection_id.setter
    def redundant_physical_connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redundant_physical_connection_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class PhysicalConnection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_point_id: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[str]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 line_operator: Optional[pulumi.Input[str]] = None,
                 peer_location: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 physical_connection_name: Optional[pulumi.Input[str]] = None,
                 port_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Physical Connection resource.

        For information about Express Connect Physical Connection and how to use it, see [What is Physical Connection](https://www.alibabacloud.com/help/en/express-connect/developer-reference/api-vpc-2016-04-28-createphysicalconnection-efficiency-channels).

        > **NOTE:** Available since v1.132.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        domestic = alicloud.expressconnect.PhysicalConnection("domestic",
            access_point_id="ap-cn-hangzhou-yh-B",
            line_operator="CT",
            peer_location="example_value",
            physical_connection_name="example_value",
            type="VPC",
            description="my domestic connection",
            port_type="1000Base-LX",
            bandwidth="100")
        international = alicloud.expressconnect.PhysicalConnection("international",
            access_point_id="ap-sg-singpore-A",
            line_operator="Other",
            peer_location="example_value",
            physical_connection_name="example_value",
            type="VPC",
            description="my domestic connection",
            port_type="1000Base-LX",
            bandwidth="100")
        ```

        ## Import

        Express Connect Physical Connection can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/physicalConnection:PhysicalConnection example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_point_id: The access point ID of the Express Connect circuit.
        :param pulumi.Input[str] bandwidth: The maximum bandwidth of the hosted connection.
        :param pulumi.Input[str] circuit_code: The circuit code of the Express Connect circuit.
        :param pulumi.Input[str] description: The description of the Express Connect circuit.
        :param pulumi.Input[str] line_operator: The connectivity provider of the Express Connect circuit. Valid values:
               - `CT`: China Telecom.
               - `CU`: China Unicom.
               - `CM`: China Mobile.
               - `CO`: Other connectivity providers in the Chinese mainland.
               - `Equinix`: Equinix.
               - `Other`: Other connectivity providers outside the Chinese mainland.
        :param pulumi.Input[str] peer_location: The geographical location of the data center.
        :param pulumi.Input[int] period: The subscription duration. Valid values:
               - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
               - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        :param pulumi.Input[str] physical_connection_name: The name of the Express Connect circuit.
        :param pulumi.Input[str] port_type: The port type of the Express Connect circuit. Valid values:
               - `100Base-T`: 100 Mbit/s copper Ethernet port.
               - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
               - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
               - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
               - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
               - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
               - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
               > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        :param pulumi.Input[str] pricing_cycle: The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
               > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        :param pulumi.Input[str] status: The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        :param pulumi.Input[str] type: The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PhysicalConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Physical Connection resource.

        For information about Express Connect Physical Connection and how to use it, see [What is Physical Connection](https://www.alibabacloud.com/help/en/express-connect/developer-reference/api-vpc-2016-04-28-createphysicalconnection-efficiency-channels).

        > **NOTE:** Available since v1.132.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        domestic = alicloud.expressconnect.PhysicalConnection("domestic",
            access_point_id="ap-cn-hangzhou-yh-B",
            line_operator="CT",
            peer_location="example_value",
            physical_connection_name="example_value",
            type="VPC",
            description="my domestic connection",
            port_type="1000Base-LX",
            bandwidth="100")
        international = alicloud.expressconnect.PhysicalConnection("international",
            access_point_id="ap-sg-singpore-A",
            line_operator="Other",
            peer_location="example_value",
            physical_connection_name="example_value",
            type="VPC",
            description="my domestic connection",
            port_type="1000Base-LX",
            bandwidth="100")
        ```

        ## Import

        Express Connect Physical Connection can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/physicalConnection:PhysicalConnection example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PhysicalConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PhysicalConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_point_id: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[str]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 line_operator: Optional[pulumi.Input[str]] = None,
                 peer_location: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 physical_connection_name: Optional[pulumi.Input[str]] = None,
                 port_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PhysicalConnectionArgs.__new__(PhysicalConnectionArgs)

            if access_point_id is None and not opts.urn:
                raise TypeError("Missing required property 'access_point_id'")
            __props__.__dict__["access_point_id"] = access_point_id
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["circuit_code"] = circuit_code
            __props__.__dict__["description"] = description
            if line_operator is None and not opts.urn:
                raise TypeError("Missing required property 'line_operator'")
            __props__.__dict__["line_operator"] = line_operator
            __props__.__dict__["peer_location"] = peer_location
            __props__.__dict__["period"] = period
            __props__.__dict__["physical_connection_name"] = physical_connection_name
            __props__.__dict__["port_type"] = port_type
            __props__.__dict__["pricing_cycle"] = pricing_cycle
            __props__.__dict__["redundant_physical_connection_id"] = redundant_physical_connection_id
            __props__.__dict__["status"] = status
            __props__.__dict__["type"] = type
            __props__.__dict__["order_id"] = None
        super(PhysicalConnection, __self__).__init__(
            'alicloud:expressconnect/physicalConnection:PhysicalConnection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_point_id: Optional[pulumi.Input[str]] = None,
            bandwidth: Optional[pulumi.Input[str]] = None,
            circuit_code: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            line_operator: Optional[pulumi.Input[str]] = None,
            order_id: Optional[pulumi.Input[str]] = None,
            peer_location: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            physical_connection_name: Optional[pulumi.Input[str]] = None,
            port_type: Optional[pulumi.Input[str]] = None,
            pricing_cycle: Optional[pulumi.Input[str]] = None,
            redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'PhysicalConnection':
        """
        Get an existing PhysicalConnection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_point_id: The access point ID of the Express Connect circuit.
        :param pulumi.Input[str] bandwidth: The maximum bandwidth of the hosted connection.
        :param pulumi.Input[str] circuit_code: The circuit code of the Express Connect circuit.
        :param pulumi.Input[str] description: The description of the Express Connect circuit.
        :param pulumi.Input[str] line_operator: The connectivity provider of the Express Connect circuit. Valid values:
               - `CT`: China Telecom.
               - `CU`: China Unicom.
               - `CM`: China Mobile.
               - `CO`: Other connectivity providers in the Chinese mainland.
               - `Equinix`: Equinix.
               - `Other`: Other connectivity providers outside the Chinese mainland.
        :param pulumi.Input[str] order_id: The ID of the order that is placed. **Note:** `order_id` takes effect only if `status` is set to `Enabled`.
        :param pulumi.Input[str] peer_location: The geographical location of the data center.
        :param pulumi.Input[int] period: The subscription duration. Valid values:
               - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
               - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        :param pulumi.Input[str] physical_connection_name: The name of the Express Connect circuit.
        :param pulumi.Input[str] port_type: The port type of the Express Connect circuit. Valid values:
               - `100Base-T`: 100 Mbit/s copper Ethernet port.
               - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
               - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
               - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
               - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
               - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
               - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
               > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        :param pulumi.Input[str] pricing_cycle: The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
               > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        :param pulumi.Input[str] status: The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        :param pulumi.Input[str] type: The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PhysicalConnectionState.__new__(_PhysicalConnectionState)

        __props__.__dict__["access_point_id"] = access_point_id
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["circuit_code"] = circuit_code
        __props__.__dict__["description"] = description
        __props__.__dict__["line_operator"] = line_operator
        __props__.__dict__["order_id"] = order_id
        __props__.__dict__["peer_location"] = peer_location
        __props__.__dict__["period"] = period
        __props__.__dict__["physical_connection_name"] = physical_connection_name
        __props__.__dict__["port_type"] = port_type
        __props__.__dict__["pricing_cycle"] = pricing_cycle
        __props__.__dict__["redundant_physical_connection_id"] = redundant_physical_connection_id
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return PhysicalConnection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> pulumi.Output[str]:
        """
        The access point ID of the Express Connect circuit.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[str]:
        """
        The maximum bandwidth of the hosted connection.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> pulumi.Output[Optional[str]]:
        """
        The circuit code of the Express Connect circuit.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the Express Connect circuit.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> pulumi.Output[str]:
        """
        The connectivity provider of the Express Connect circuit. Valid values:
        - `CT`: China Telecom.
        - `CU`: China Unicom.
        - `CM`: China Mobile.
        - `CO`: Other connectivity providers in the Chinese mainland.
        - `Equinix`: Equinix.
        - `Other`: Other connectivity providers outside the Chinese mainland.
        """
        return pulumi.get(self, "line_operator")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> pulumi.Output[str]:
        """
        The ID of the order that is placed. **Note:** `order_id` takes effect only if `status` is set to `Enabled`.
        """
        return pulumi.get(self, "order_id")

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> pulumi.Output[str]:
        """
        The geographical location of the data center.
        """
        return pulumi.get(self, "peer_location")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        The subscription duration. Valid values:
        - If `pricing_cycle` is set to `Month`. Valid values: `1` to `9`.
        - If `pricing_cycle` is set to `Year`. Valid values: `1` to `5`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="physicalConnectionName")
    def physical_connection_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the Express Connect circuit.
        """
        return pulumi.get(self, "physical_connection_name")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> pulumi.Output[Optional[str]]:
        """
        The port type of the Express Connect circuit. Valid values:
        - `100Base-T`: 100 Mbit/s copper Ethernet port.
        - `1000Base-T`: 1000 Mbit/s copper Ethernet port.
        - `1000Base-LX`: 1000 Mbit/s single-mode optical port (10 km).
        - `10GBase-T`: 10000 Mbit/s copper Ethernet port.
        - `10GBase-LR`: 10000 Mbit/s single-mode optical port (10 km).
        - `40GBase-LR`: 40000 Mbit/s single-mode optical port.
        - `100GBase-LR`: 100000 Mbit/s single-mode optical port.
        > **NOTE:** From version 1.185.0, `port_type` can be set to `40GBase-LR`, `100GBase-LR`. From version 1.230.1, `port_type` cannot be modified.
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> pulumi.Output[Optional[str]]:
        """
        The billing cycle of the subscription. Default value: `Month`. Valid values: `Month`, `Year`.
        > **NOTE:** `period` and `pricing_cycle` are valid only when `status` is set to `Enabled`.
        """
        return pulumi.get(self, "pricing_cycle")

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the redundant Express Connect circuit. **NOTE:** From version 1.230.1, `redundant_physical_connection_id` cannot be modified.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the Express Connect circuit. Valid values: `Confirmed`, `Enabled`, `Canceled`, `Terminated`. **NOTE:** From version 1.230.1, `status` can be set to `Confirmed`. If you want to set `status` to `Enabled`, `period` must be set.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of Express Connect circuit. Default value: `VPC`. Valid values: `VPC`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .access_configuration import *
from .access_configuration_provisioning import *
from .access_management import *
from .directory import *
from .get_access_assignments import *
from .get_access_configurations import *
from .get_directories import *
from .get_groups import *
from .get_scim_server_credentials import *
from .get_service import *
from .get_users import *
from .group import *
from .scim_server_credential import *
from .user import *
from .user_attachment import *
from ._inputs import *
from . import outputs
